/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  Copyright (C) 2006-2010 XNeur Team
 *
 */

#ifndef _CALLBACKS_H_
#define _CALLBACKS_H_

#include <gtk/gtk.h>

typedef struct { 
	void *x;
	void *y; 
	void *z;
} xyz_t;

void on_addbutton_clicked(GtkButton *button, gpointer user_data);
void on_editbutton_clicked(GtkButton *button, gpointer user_data);
void on_deletebutton_clicked(GtkButton *button, gpointer user_data);
void on_okbutton_clicked(GtkButton *button, gpointer user_data);
void on_cancelbutton_clicked(GtkButton *button, gpointer user_data);

gboolean on_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
gboolean on_key_release_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);

#endif /* _CALLBACKS_H_ */
